==> mauticGIT-Test-20251111_133203.tar.gz: var/www/html/mauticGIT-Test/var/tmp/twig/38/38fd422dee3775964e7f6d84fbb00b72.php <==
<?php

use Twig\Environment;
use Twig\Error\LoaderError;
use Twig\Error\RuntimeError;
use Twig\Extension\CoreExtension;
use Twig\Extension\SandboxExtension;
use Twig\Markup;
use Twig\Sandbox\SecurityError;
use Twig\Sandbox\SecurityNotAllowedTagError;
use Twig\Sandbox\SecurityNotAllowedFilterError;
use Twig\Sandbox\SecurityNotAllowedFunctionError;
use Twig\Source;
use Twig\Template;
use Twig\TemplateWrapper;

/* @bundles/CoreBundle/Assets/js/libraries/filemanager/jquery-ui/themes/smoothness/images/ui-icons_222222_256x240.png */
class __TwigTemplate_acaaa3b0f7e5fde6a13e15a559ae686f extends Template
{
    private Source $source;
    /**
     * @var array<string, Template>
     */
    private array $macros = [];

    public function __construct(Environment $env)
    {
        parent::__construct($env);

        $this->source = $this->getSourceContext();

        $this->parent = false;

        $this->blocks = [
        ];
    }

    protected function doDisplay(array $context, array $blocks = []): iterable
    {
        $macros = $this->macros;
        // line 1
        yield "PNG

\000\000\000
IHDR\000\000\000\000\000\000\000\000\000Er@\000\000\000gAMA\000\000a\000\000\000 cHRM\000\000z&\000\000\000\000\000\000\000\000\000u0\000\000`\000\000:\000\000pQ<\000\000\000bKGD\000\"b\000\000\000tIME
%'E\000\000TIDATxm%Uy
\$!,h ,%&@|IEMrݱD2;f܉A^\$5Ƣj^K@U-wWD`|q\"t>ν3}S~9}<><yNp\tM)`\tpxht%\000yYD^`Or%`:
\$%{\0000LL?a|6܉]A7P'@/:]5JH&ay2:8ty@#*'?t緝;Ywגm׸\000{>|Dg7\\J{4K3tfZޱ`7u7Yɶ~f]<4m*<%%{^`FR\000
\tl8<Oh8<Ok2\000n6cL`>]=u\$,`&+hk6J_*|K0\000?@lxdom]L3ݞߌ0.;TE,;4tMOmPLUA&e+`8u]577~\"h8<Oh8<]C8YsZ}iA ֠)Ȟs\000W.!m.
z[#R䨚
\\R{v
r\tR ?˝#[|f`\000y)A-QN
4wϮ:Kr{河3ZP!0t{l\\YwSnPIA.Vm-R
\$ysI@;eغX.vYvB
\000n]gWcVn*ôy\000T=Mhpt
+3
'@\tpx4\000
'@\tpC`=x?.jlk]R
Q.ޫ5@P,[Zj6ƵKɟڕ[ ,P/5/thzG]Yn!wk9څR+@Ktťa.mKuD<i5Еcn[@z@VmPgQOc:Ӕ%{%܄.緯ןߖF\000{h'@{\"ȕ.=>M篂U!LgK\\At\$VrX˒\000`LoMe/R+X.X.]L]Nq%e\0007w\"<
ּp뻴ʩ@\t uǤ
OO7\000
'@\tpx4\000 PdrvM{wQve{Ȯ]0d1w%L,vQwqyyx`]jW.!WWl/D3,v܁6]iZ<:IݯtM~9UPi!snS!QyU緯lJȚ!\$(7-/ޮB¤F[^)F#*U\$`7\\!OUŪ3ǐ_J:𨃏ܽX6X!|.!}t\$ePROQա/P[Cmb,=XA!tho14]Zh=Oh8<#@keEٲM&IKѢ&b04(.%thtIH2>Dgͳ]ݢ@NE]hɟ|T=m5@.#BW2wQ׿¨alrvEb)n#ය݄F/N6%t]KX\"nz\"t.'`[A-<d\000#]/\\#
sDbVGӫ
@u>y-LTi \trgW=)lj&˺;YeF,6CG_0l;y1|\0005'@\tpx4\000SLT_ʿߐ:ADV\\cK
!e8L}F{=.y0~w,ݭ9^n\tgH<sٌgd}ܠ):\$:N\"<S!,qg
駹\\v'g{;W3pImbni;J)\000s\000<.\$_.[5{IV\\ⷸ\"[\$@d\tKe%b!ѮFn0#l§8\000o(\$%f)@6[L9(?Ko?wjSl2^9\000EL
VH)0ͭ!k@}CnU:l|4
2sPRQ,Qgdp6صpKi*B?O_1?Ʒd'%d;§\\k:?r7p#'reL3[[\$꿟3D
N_8״)<z'i>]Y,b}H!0La4-Uڣ\$R|crQx/a_seRmDz\000\$V\\
3<ɔ0㗹1VD<n&S\tLC4*5O`KA`5D\$n}5Bf\"GPM\trU/j\"\$!f+{/fjtkPt쇘S\000ӹr#q>#a=5!*,6~ ^#Jt
Wg{ȃsd,o9X1\t?*uuB,=`޻'1l\$[Gx4\000
'@\tDΞ\000-z)E}:g˖\tgÁyk>fiNa~ɏk`.73PȸҜ;+
ZpMlbinFݬLپȓ4 :a.0JN.pk8NPx\\lh݅x2iǹ?OH5M@.K4p\\a/>ay%^zU25O'0VOsMR4\"0VܞFqyYEL0])PK~Irx/Qs*SL1fn>6U4>i#\\}cJjrjo_u8n,JFgyFk6a[0y|kS\\6+)L*g\tEDخq|Y_'-?Z\";<Wϼ=
[\\IL}7OqX
4<z7=~CP6w'ƟL~*?7ȳg\000%npMBC{
L^O2;C!<n\$7B5F&XQ?̧>-c%DP]y_VaX1uҗEc_t'[PP>`4B \"O7ՑF3
\000<5ϝ|B.0#bb],ҥK{/QWܯd0~.ꏜ}eK
Y@3>?_\"X,u5OԘ(xsG4DI\000
4\000
'@\tp4\000XNIMs(,ѡކ<&R=>@]ZG^
_Hk|p7rFp,/^>G-B+7(z3d-A^'qzj
z_`I:L0T|aɄ܇<SIU̅囌3I'.GÓҐl{UR̌\"gh.Gj,NUi0`rƀ1\000GlKTQzy\"?or>'/CTS̤
U
(.2Rr ?<
aGBKsRƔ[IlcylU_ɷxO\000\tQH1NcӺ#?5f4ߣ\0003lgGA<aW9w@I68F߮U3hC'aQ?m*w\\9\$;`[6q5e(|E\"8ODHF+~Sm<*Mʖ
._S9<ΐҫQw ŉW)p?
gW,

'!pFQ8_/_z\000{!XZ7&9W&Ef!GU)Y:l{`s6Ãld,GyxIC
_kJwiKs88Mq,y
SV{ycPI#ిűoos:*i@Z8]^ext7)%-T,)O\\NKQ|0w\000fKl.Xګ=_;fl⧅;ϱm ]/OB.ySW/))xsp;+<.pƴjqICE[kOy\000\000
'@Q\$6^=|;6o\\
|ˤt_⽃G}{KT{q8b
 vK\"kK/n8'@e6e^jԪp؀l)l㩻7hkdC]H4nnF[:b\tl[ꑬ'n(|[Ƹ4%t]BFh%Z`%>njԄ&\"\\r'VZvD)ykCbW;I[k!fuiQ*tWsN_~W<
g)'8}ږj\000HzD6\0006Dkx3?xFy
zno\000O+v,bcxsLwxtnGĝlNn2ھIOΐlƟw
gkг=ޜlAl)l[k;)\"W2:-.H٥aq66\$\\0oqǌcC[Oh8<O\":F@j1Xg dbݖ3<cw
'úlajdiiK[:Jw@!? ~iy
0\\]#cY9%&
BsQ@6[sJ8NIW߭C'QۥdFPM\000P8a#\000\$Q(+K\t:eBziX|N~<ƜGc̥5P\\|t+ss(A[P}\000
|-Vܘ `UZLhv\$0sƼyihH ?KQ`a#d*AS#\\j=i,]6\000
'@\tpx4Ezl@dh\000!MUc]\"!@n~RJ%O2!Eah=P~`\$AGSr52rb&ATZ-JC\000-W8?<8ʽ*[4FTjGp8&)vU<Uji,~|?=lWj\000˻RR\$3}n|TK\0005..NQE\\)k)ʿ\000xS,qEi!{\000q}g.r
gUSqs=W2^\000).[ABhW.ywȼ=}06O8A6ϫ
O
'@\tpx4lԕT
ž--@]-\\A+õ2{]\$g-h\"MM-|9ZvY?0䷕_,mo9\taa.IK*VJ6[B:n.aP/0Ks\000Զ_rSFOVh\t (ɸ5@Y\tP}x5yoEZ=UJȯ|?tk3=hvn'SO!`\000Շ]~r\tպpSn=ҝ/A=p/cNء葜&(G)JG\$6yI/,MP%P(iCC~[vWB篾ꒈV\$˹}工(k&
Z^8S8>zELHWW+wx0-pxk`\tpx4\000
'@\tpAܣDkH2u]AzwnPExFyAum\t0F0bG:1;L6|CGICHRݿ6y~˘{o}@]Q~\"h8<Oh8/~B\tP-d׻͒\000£\"D
;R򠫹 `d] a{ -+PS#R3@O z-̒
¿rvJQz\000`W_9HGx\\EA2͌r͠&~U\000>wS[Σ- `9'C~C@eCٹq_\tX\000zN\000\000\000%tEXtdate:create\0002016-09-14T13:32:39-04:00z\000\000\000%tEXtdate:modify\0002015-06-01T10:37:21-04:00(An\000\000\000tEXtSoftware\000Adobe ImageReadyqe<\000\000\000\000IENDB`";
        yield from [];
    }

    /**
     * @codeCoverageIgnore
     */
    public function getTemplateName(): string
    {
        return "@bundles/CoreBundle/Assets/js/libraries/filemanager/jquery-ui/themes/smoothness/images/ui-icons_222222_256x240.png";
    }

    /**
     * @codeCoverageIgnore
     */
    public function getDebugInfo(): array
    {
        return array (  42 => 1,);
    }

    public function getSourceContext(): Source
    {
        return new Source("", "@bundles/CoreBundle/Assets/js/libraries/filemanager/jquery-ui/themes/smoothness/images/ui-icons_222222_256x240.png", "/var/www/mautic-ktn/app/bundles/CoreBundle/Assets/js/libraries/filemanager/jquery-ui/themes/smoothness/images/ui-icons_222222_256x240.png");
    }
}

==> mauticGIT-Test-20260119_091040.tar.gz: var/www/html/mauticGIT-Test/var/tmp/twig/38/38fd422dee3775964e7f6d84fbb00b72.php <==
<?php

use Twig\Environment;
use Twig\Error\LoaderError;
use Twig\Error\RuntimeError;
use Twig\Extension\CoreExtension;
use Twig\Extension\SandboxExtension;
use Twig\Markup;
use Twig\Sandbox\SecurityError;
use Twig\Sandbox\SecurityNotAllowedTagError;
use Twig\Sandbox\SecurityNotAllowedFilterError;
use Twig\Sandbox\SecurityNotAllowedFunctionError;
use Twig\Source;
use Twig\Template;
use Twig\TemplateWrapper;

/* @bundles/CoreBundle/Assets/js/libraries/filemanager/jquery-ui/themes/smoothness/images/ui-icons_222222_256x240.png */
class __TwigTemplate_acaaa3b0f7e5fde6a13e15a559ae686f extends Template
{
    private Source $source;
    /**
     * @var array<string, Template>
     */
    private array $macros = [];

    public function __construct(Environment $env)
    {
        parent::__construct($env);

        $this->source = $this->getSourceContext();

        $this->parent = false;

        $this->blocks = [
        ];
    }

    protected function doDisplay(array $context, array $blocks = []): iterable
    {
        $macros = $this->macros;
        // line 1
        yield "PNG

\000\000\000
IHDR\000\000\000\000\000\000\000\000\000Er@\000\000\000gAMA\000\000a\000\000\000 cHRM\000\000z&\000\000\000\000\000\000\000\000\000u0\000\000`\000\000:\000\000pQ<\000\000\000bKGD\000\"b\000\000\000tIME
%'E\000\000TIDATxm%Uy
\$!,h ,%&@|IEMrݱD2;f܉A^\$5Ƣj^K@U-wWD`|q\"t>ν3}S~9}<><yNp\tM)`\tpxht%\000yYD^`Or%`:
\$%{\0000LL?a|6܉]A7P'@/:]5JH&ay2:8ty@#*'?t緝;Ywגm׸\000{>|Dg7\\J{4K3tfZޱ`7u7Yɶ~f]<4m*<%%{^`FR\000
\tl8<Oh8<Ok2\000n6cL`>]=u\$,`&+hk6J_*|K0\000?@lxdom]L3ݞߌ0.;TE,;4tMOmPLUA&e+`8u]577~\"h8<Oh8<]C8YsZ}iA ֠)Ȟs\000W.!m.
z[#R䨚
\\R{v
r\tR ?˝#[|f`\000y)A-QN
4wϮ:Kr{河3ZP!0t{l\\YwSnPIA.Vm-R
\$ysI@;eغX.vYvB
\000n]gWcVn*ôy\000T=Mhpt
+3
'@\tpx4\000
'@\tpC`=x?.jlk]R
Q.ޫ5@P,[Zj6ƵKɟڕ[ ,P/5/thzG]Yn!wk9څR+@Ktťa.mKuD<i5Еcn[@z@VmPgQOc:Ӕ%{%܄.緯ןߖF\000{h'@{\"ȕ.=>M篂U!LgK\\At\$VrX˒\000`LoMe/R+X.X.]L]Nq%e\0007w\"<
ּp뻴ʩ@\t uǤ
OO7\000
'@\tpx4\000 PdrvM{wQve{Ȯ]0d1w%L,vQwqyyx`]jW.!WWl/D3,v܁6]iZ<:IݯtM~9UPi!snS!QyU緯lJȚ!\$(7-/ޮB¤F[^)F#*U\$`7\\!OUŪ3ǐ_J:𨃏ܽX6X!|.!}t\$ePROQա/P[Cmb,=XA!tho14]Zh=Oh8<#@keEٲM&IKѢ&b04(.%thtIH2>Dgͳ]ݢ@NE]hɟ|T=m5@.#BW2wQ׿¨alrvEb)n#ය݄F/N6%t]KX\"nz\"t.'`[A-<d\000#]/\\#
sDbVGӫ
@u>y-LTi \trgW=)lj&˺;YeF,6CG_0l;y1|\0005'@\tpx4\000SLT_ʿߐ:ADV\\cK
!e8L}F{=.y0~w,ݭ9^n\tgH<sٌgd}ܠ):\$:N\"<S!,qg
駹\\v'g{;W3pImbni;J)\000s\000<.\$_.[5{IV\\ⷸ\"[\$@d\tKe%b!ѮFn0#l§8\000o(\$%f)@6[L9(?Ko?wjSl2^9\000EL
VH)0ͭ!k@}CnU:l|4
2sPRQ,Qgdp6صpKi*B?O_1?Ʒd'%d;§\\k:?r7p#'reL3[[\$꿟3D
N_8״)<z'i>]Y,b}H!0La4-Uڣ\$R|crQx/a_seRmDz\000\$V\\
3<ɔ0㗹1VD<n&S\tLC4*5O`KA`5D\$n}5Bf\"GPM\trU/j\"\$!f+{/fjtkPt쇘S\000ӹr#q>#a=5!*,6~ ^#Jt
Wg{ȃsd,o9X1\t?*uuB,=`޻'1l\$[Gx4\000
'@\tDΞ\000-z)E}:g˖\tgÁyk>fiNa~ɏk`.73PȸҜ;+
ZpMlbinFݬLپȓ4 :a.0JN.pk8NPx\\lh݅x2iǹ?OH5M@.K4p\\a/>ay%^zU25O'0VOsMR4\"0VܞFqyYEL0])PK~Irx/Qs*SL1fn>6U4>i#\\}cJjrjo_u8n,JFgyFk6a[0y|kS\\6+)L*g\tEDخq|Y_'-?Z\";<Wϼ=
[\\IL}7OqX
4<z7=~CP6w'ƟL~*?7ȳg\000%npMBC{
L^O2;C!<n\$7B5F&XQ?̧>-c%DP]y_VaX1uҗEc_t'[PP>`4B \"O7ՑF3
\000<5ϝ|B.0#bb],ҥK{/QWܯd0~.ꏜ}eK
Y@3>?_\"X,u5OԘ(xsG4DI\000
4\000
'@\tp4\000XNIMs(,ѡކ<&R=>@]ZG^
_Hk|p7rFp,/^>G-B+7(z3d-A^'qzj
z_`I:L0T|aɄ܇<SIU̅囌3I'.GÓҐl{UR̌\"gh.Gj,NUi0`rƀ1\000GlKTQzy\"?or>'/CTS̤
U
(.2Rr ?<
aGBKsRƔ[IlcylU_ɷxO\000\tQH1NcӺ#?5f4ߣ\0003lgGA<aW9w@I68F߮U3hC'aQ?m*w\\9\$;`[6q5e(|E\"8ODHF+~Sm<*Mʖ
._S9<ΐҫQw ŉW)p?
gW,

'!pFQ8_/_z\000{!XZ7&9W&Ef!GU)Y:l{`s6Ãld,GyxIC
_kJwiKs88Mq,y
SV{ycPI#ిűoos:*i@Z8]^ext7)%-T,)O\\NKQ|0w\000fKl.Xګ=_;fl⧅;ϱm ]/OB.ySW/))xsp;+<.pƴjqICE[kOy\000\000
'@Q\$6^=|;6o\\
|ˤt_⽃G}{KT{q8b
 vK\"kK/n8'@e6e^jԪp؀l)l㩻7hkdC]H4nnF[:b\tl[ꑬ'n(|[Ƹ4%t]BFh%Z`%>njԄ&\"\\r'VZvD)ykCbW;I[k!fuiQ*tWsN_~W<
g)'8}ږj\000HzD6\0006Dkx3?xFy
zno\000O+v,bcxsLwxtnGĝlNn2ھIOΐlƟw
gkг=ޜlAl)l[k;)\"W2:-.H٥aq66\$\\0oqǌcC[Oh8<O\":F@j1Xg dbݖ3<cw
'úlajdiiK[:Jw@!? ~iy
0\\]#cY9%&
BsQ@6[sJ8NIW߭C'QۥdFPM\000P8a#\000\$Q(+K\t:eBziX|N~<ƜGc̥5P\\|t+ss(A[P}\000
|-Vܘ `UZLhv\$0sƼyihH ?KQ`a#d*AS#\\j=i,]6\000
'@\tpx4Ezl@dh\000!MUc]\"!@n~RJ%O2!Eah=P~`\$AGSr52rb&ATZ-JC\000-W8?<8ʽ*[4FTjGp8&)vU<Uji,~|?=lWj\000˻RR\$3}n|TK\0005..NQE\\)k)ʿ\000xS,qEi!{\000q}g.r
gUSqs=W2^\000).[ABhW.ywȼ=}06O8A6ϫ
O
'@\tpx4lԕT
ž--@]-\\A+õ2{]\$g-h\"MM-|9ZvY?0䷕_,mo9\taa.IK*VJ6[B:n.aP/0Ks\000Զ_rSFOVh\t (ɸ5@Y\tP}x5yoEZ=UJȯ|?tk3=hvn'SO!`\000Շ]~r\tպpSn=ҝ/A=p/cNء葜&(G)JG\$6yI/,MP%P(iCC~[vWB篾ꒈV\$˹}工(k&
Z^8S8>zELHWW+wx0-pxk`\tpx4\000
'@\tpAܣDkH2u]AzwnPExFyAum\t0F0bG:1;L6|CGICHRݿ6y~˘{o}@]Q~\"h8<Oh8/~B\tP-d׻͒\000£\"D
;R򠫹 `d] a{ -+PS#R3@O z-̒
¿rvJQz\000`W_9HGx\\EA2͌r͠&~U\000>wS[Σ- `9'C~C@eCٹq_\tX\000zN\000\000\000%tEXtdate:create\0002016-09-14T13:32:39-04:00z\000\000\000%tEXtdate:modify\0002015-06-01T10:37:21-04:00(An\000\000\000tEXtSoftware\000Adobe ImageReadyqe<\000\000\000\000IENDB`";
        yield from [];
    }

    /**
     * @codeCoverageIgnore
     */
    public function getTemplateName(): string
    {
        return "@bundles/CoreBundle/Assets/js/libraries/filemanager/jquery-ui/themes/smoothness/images/ui-icons_222222_256x240.png";
    }

    /**
     * @codeCoverageIgnore
     */
    public function getDebugInfo(): array
    {
        return array (  42 => 1,);
    }

    public function getSourceContext(): Source
    {
        return new Source("", "@bundles/CoreBundle/Assets/js/libraries/filemanager/jquery-ui/themes/smoothness/images/ui-icons_222222_256x240.png", "/var/www/html/mauticGIT-Test/app/bundles/CoreBundle/Assets/js/libraries/filemanager/jquery-ui/themes/smoothness/images/ui-icons_222222_256x240.png");
    }
}
